@@ -25,11 +25,6 @@ extern "C" {
 #endif
 
 
-#ifndef errno
-extern int errno
-#endif
-
-
 #include <algorithm>
 
 #define OUT(level) DEBUG_OUT(level, MODULE_TREE)
@@ -1165,14 +1160,12 @@ bool file_copy( std::string origin, std::string target )
 
     const int SIZE = 1024*1024;
     char buffer[SIZE];
-/*
-    if( errno != 0 )
-	return false;
-
-    DEBUG( OUT( 3 ) << "errno  == 0\n"  );
-*/
 
+#ifdef NO_STD_FEOF
+    if( ferror( o ) || ferror( t ) )
+#else
     if( std::ferror( o ) || std::ferror( t ) )
+#endif
 	return false;
 
     DEBUG( OUT( 3 ) << "no ferror\n"  );
@@ -1184,7 +1177,11 @@ bool file_copy( std::string origin, std::string target )
 
 	DEBUG( OUT(3)( "wrote %d: bytes error: %d\n", rsize, std::ferror( o ) ) );
 
+#ifdef NO_STD_FEOF
+    } while( !feof( o ) && !ferror( o ) && !ferror( t ) );
+#else
     } while( !std::feof( o ) && !std::ferror( o ) && !std::ferror( t ) );
+#endif
 
     std::fclose( o );
     std::fclose( t );
